@@ -469,6 +469,9 @@ class DiffracBasis(PseudoMotorController):
             elif engine_name == "eulerians":
                 values = [pseudo_pos[8], pseudo_pos[9], pseudo_pos[10]]
 
+        # getWavelength updates wavelength in the library in case automatic
+        # energy update is set. Needed before computing trajectories.
+
         self.getWavelength()
 
         solutions = self._solutions(values, curr_physical_pos)
@@ -484,6 +487,9 @@ class DiffracBasis(PseudoMotorController):
         # physical values are not equal to the expected len of the
         # geometry axes.
         
+        # getWavelength updates wavelength in the library in case automatic
+        # energy update is set. Needed before computing trajectories.
+
         self.getWavelength()
             
 
@@ -748,6 +754,18 @@ class DiffracBasis(PseudoMotorController):
         #         (len(values),
         #          len(self.engine.pseudo_axis_names_get()),
         #          self.engine.name_get())
+        # getWavelength updates wavelength in the library in case automatic
+        # energy update is set. Needed before computing trajectories.
+     
+        self.getWavelength()
+        
+        # Read current motor positions
+        motor_position = []
+        for i in range(0, self.nb_ph_axes):
+            motor = self.GetMotor(i)
+            motor_position.append(motor.get_position(cache=False).value)
+        self.geometry.axis_values_set(motor_position, USER)
+            
         curr_physical_pos = self.geometry.axis_values_get(USER)
         solutions = self._solutions(values, curr_physical_pos)
         self.trajectorylist = [item.geometry_get().axis_values_get(USER)
@@ -805,7 +823,7 @@ class DiffracBasis(PseudoMotorController):
         motor_position = []
         for i in range(0, self.nb_ph_axes):
             motor = self.GetMotor(i)
-            motor_position.append(motor.position.value)
+            motor_position.append(motor.get_position(cache=False).value)
         self.geometry.axis_values_set(motor_position, USER)
         newref = self.sample.add_reflection(
             self.geometry, self.detector, value[0], value[1], value[2])
@@ -960,9 +978,13 @@ class DiffracBasis(PseudoMotorController):
                 geometry.axis_values_set(values[6:], USER)
                 reflection.geometry_set(geometry)
 
-    def setLoadCrystal(self, value):  # value: complete path of the file with the crystal to set
+    def setLoadCrystal(self, value):
+        """Load crystal information from a file. Ignore wavelength information.
+
+        :param value: complete path of the file with the crystal to set
+        :type value: string
+        """
         # Read the file
-        
         with open(value, 'r') as crystal_file:
             self._loadcrystal = value
 
@@ -981,10 +1003,6 @@ class DiffracBasis(PseudoMotorController):
                     # Remove all reflections from crystal (there should not be any ... but just in case)
                     for ref in self.sample.reflections_get():
                         self.sample.del_reflection(ref)
-                elif line.find("Wavelength") != -1:
-                    line = line.replace(" ", "")
-                    wavelength = float(line.split("Wavelength",1)[1]) # The value will be set after creating the new geometry with the reflections
-                    self.geometry.wavelength_set(wavelength, USER)
                 elif line.find("A") != -1 and line.find("B") != -1 and line.find("C") != -1:
                     par_line = line.split(" ")
                     avalue = float(par_line[1])
@@ -1323,7 +1341,10 @@ class DiffracBasis(PseudoMotorController):
         self._autoenergyupdate = value
 
     def setComputeHKL(self, value):
-              
+         
+        # getWavelength updates wavelength in the library in case automatic
+        # energy update is set. Needed before computing trajectories.
+     
         self.getWavelength()
             
 
