@@ -98,7 +98,12 @@ class ExpDescriptionEditor(Qt.QWidget, TaurusBaseWidget):
         self.connect(self.ui.filenameLE, Qt.SIGNAL('textEdited (QString)'), self.onFilenameLEEdited)
         self.connect(self.ui.channelEditor.getQModel(), Qt.SIGNAL('dataChanged (QModelIndex, QModelIndex)'), self._updateButtonBox)
         self.connect(self.ui.channelEditor.getQModel(), Qt.SIGNAL('modelReset ()'), self._updateButtonBox)
-        self.connect(self.ui.preScanList, Qt.SIGNAL('dataChanged'), self.onPreScanSnapshotChanged)
+        preScanList = self.ui.preScanList
+        self.connect(preScanList, Qt.SIGNAL('dataChanged'),
+                     self.onPreScanSnapshotChanged)
+        #TODO: For Taurus 4 compatibility
+        if hasattr(preScanList, "dataChangedSignal"):
+            preScanList.dataChangedSignal.connect(self.onPreScanSnapshotChanged)
         self.connect(self.ui.choosePathBT, Qt.SIGNAL('clicked ()'), self.onChooseScanDirButtonClicked)
         
         self.__plotManager = None
@@ -204,14 +209,24 @@ class ExpDescriptionEditor(Qt.QWidget, TaurusBaseWidget):
 
         #set the measurement group ComboBox
         self.ui.activeMntGrpCB.clear()
-        self.ui.activeMntGrpCB.addItems(sorted(self._localConfig['MntGrpConfigs'].keys()))
-        idx = self.ui.activeMntGrpCB.findText(activeMntGrpName)
+        mntGrpLabels = []
+        for _, mntGrpConf in self._localConfig['MntGrpConfigs'].items():
+            # get labels to visualize names with lower and upper case
+            mntGrpLabels.append(mntGrpConf['label'])
+        self.ui.activeMntGrpCB.addItems(sorted(mntGrpLabels))
+        idx = self.ui.activeMntGrpCB.findText(activeMntGrpName,
+                                              # case insensitive find
+                                              Qt.Qt.MatchFixedString)
         self.ui.activeMntGrpCB.setCurrentIndex(idx)
 
         #set the system snapshot list
         psl = self._localConfig.get('PreScanSnapshot')  #I get it before clearing because clear() changes the _localConfig
+        # TODO: For Taurus 4 compatibility
+        psl_fullname = []
+        for name, display in psl:
+            psl_fullname.append(("tango://%s" % name, display))
         self.ui.preScanList.clear()
-        self.ui.preScanList.addModels(psl)
+        self.ui.preScanList.addModels(psl_fullname)
 
         #other settings
         self.ui.filenameLE.setText(", ".join(self._localConfig['ScanFile']))
@@ -236,8 +251,9 @@ class ExpDescriptionEditor(Qt.QWidget, TaurusBaseWidget):
         #make sure that no empty measurement groups are written
         for mgname, mgconfig in conf.get('MntGrpConfigs', {}).items():
             if mgconfig is not None and not mgconfig.get('controllers'):
+                mglabel = mgconfig['label']
                 Qt.QMessageBox.information(self, "Empty Measurement group",
-                "The measurement group '%s' is empty. Fill it (or delete it) before applying" % mgname,
+                "The measurement group '%s' is empty. Fill it (or delete it) before applying" % mglabel,
                 Qt.QMessageBox.Ok)
                 self.changeActiveMntGrp(mgname)
                 return False
@@ -270,7 +286,9 @@ class ExpDescriptionEditor(Qt.QWidget, TaurusBaseWidget):
 
         self._localConfig['ActiveMntGrp'] = activeMntGrpName
 
-        i = self.ui.activeMntGrpCB.findText(activeMntGrpName, Qt.Qt.MatchExactly)
+        i = self.ui.activeMntGrpCB.findText(activeMntGrpName,
+                                            # case insensitive find
+                                            Qt.Qt.MatchFixedString)
         self.ui.activeMntGrpCB.setCurrentIndex(i)
         mgconfig = self._localConfig['MntGrpConfigs'][activeMntGrpName]
         self.ui.channelEditor.getQModel().setDataSource(mgconfig)
@@ -360,9 +378,11 @@ class ExpDescriptionEditor(Qt.QWidget, TaurusBaseWidget):
         for e in items:
             nfo = ms.getElementInfo(e.src)
             if nfo is None:
-                preScanList.append((e.src, e.display))
+                full_name = e.src; display = e.display
             else:
-                preScanList.append((nfo.full_name, nfo.name))
+                full_name = nfo.full_name; display = nfo.name
+            # TODO: For Taurus 4 compatibility
+            preScanList.append((full_name.lstrip("tango://"), display))
         self._localConfig['PreScanSnapshot'] = preScanList
         self._setDirty(True)
         
